import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CostExplorerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CostExplorerClient";
import { ListSavingsPlansPurchaseRecommendationGenerationRequest, ListSavingsPlansPurchaseRecommendationGenerationResponse } from "../models/models_0";
/**
 * @public
 *
 * The input for {@link ListSavingsPlansPurchaseRecommendationGenerationCommand}.
 */
export interface ListSavingsPlansPurchaseRecommendationGenerationCommandInput extends ListSavingsPlansPurchaseRecommendationGenerationRequest {
}
/**
 * @public
 *
 * The output of {@link ListSavingsPlansPurchaseRecommendationGenerationCommand}.
 */
export interface ListSavingsPlansPurchaseRecommendationGenerationCommandOutput extends ListSavingsPlansPurchaseRecommendationGenerationResponse, __MetadataBearer {
}
/**
 * @public
 * <p>Retrieves a list of your historical recommendation generations within the past 30
 *       days.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CostExplorerClient, ListSavingsPlansPurchaseRecommendationGenerationCommand } from "@aws-sdk/client-cost-explorer"; // ES Modules import
 * // const { CostExplorerClient, ListSavingsPlansPurchaseRecommendationGenerationCommand } = require("@aws-sdk/client-cost-explorer"); // CommonJS import
 * const client = new CostExplorerClient(config);
 * const input = { // ListSavingsPlansPurchaseRecommendationGenerationRequest
 *   GenerationStatus: "SUCCEEDED" || "PROCESSING" || "FAILED",
 *   RecommendationIds: [ // RecommendationIdList
 *     "STRING_VALUE",
 *   ],
 *   PageSize: Number("int"),
 *   NextPageToken: "STRING_VALUE",
 * };
 * const command = new ListSavingsPlansPurchaseRecommendationGenerationCommand(input);
 * const response = await client.send(command);
 * // { // ListSavingsPlansPurchaseRecommendationGenerationResponse
 * //   GenerationSummaryList: [ // GenerationSummaryList
 * //     { // GenerationSummary
 * //       RecommendationId: "STRING_VALUE",
 * //       GenerationStatus: "SUCCEEDED" || "PROCESSING" || "FAILED",
 * //       GenerationStartedTime: "STRING_VALUE",
 * //       GenerationCompletionTime: "STRING_VALUE",
 * //       EstimatedCompletionTime: "STRING_VALUE",
 * //     },
 * //   ],
 * //   NextPageToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListSavingsPlansPurchaseRecommendationGenerationCommandInput - {@link ListSavingsPlansPurchaseRecommendationGenerationCommandInput}
 * @returns {@link ListSavingsPlansPurchaseRecommendationGenerationCommandOutput}
 * @see {@link ListSavingsPlansPurchaseRecommendationGenerationCommandInput} for command's `input` shape.
 * @see {@link ListSavingsPlansPurchaseRecommendationGenerationCommandOutput} for command's `response` shape.
 * @see {@link CostExplorerClientResolvedConfig | config} for CostExplorerClient's `config` shape.
 *
 * @throws {@link InvalidNextTokenException} (client fault)
 *  <p>The pagination token is invalid. Try again without a pagination token.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>You made too many calls in a short period of time. Try again later.</p>
 *
 * @throws {@link CostExplorerServiceException}
 * <p>Base exception class for all service exceptions from CostExplorer service.</p>
 *
 */
export declare class ListSavingsPlansPurchaseRecommendationGenerationCommand extends $Command<ListSavingsPlansPurchaseRecommendationGenerationCommandInput, ListSavingsPlansPurchaseRecommendationGenerationCommandOutput, CostExplorerClientResolvedConfig> {
    readonly input: ListSavingsPlansPurchaseRecommendationGenerationCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: ListSavingsPlansPurchaseRecommendationGenerationCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CostExplorerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListSavingsPlansPurchaseRecommendationGenerationCommandInput, ListSavingsPlansPurchaseRecommendationGenerationCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
