import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CostExplorerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CostExplorerClient";
import { ProvideAnomalyFeedbackRequest, ProvideAnomalyFeedbackResponse } from "../models/models_0";
/**
 * @public
 *
 * The input for {@link ProvideAnomalyFeedbackCommand}.
 */
export interface ProvideAnomalyFeedbackCommandInput extends ProvideAnomalyFeedbackRequest {
}
/**
 * @public
 *
 * The output of {@link ProvideAnomalyFeedbackCommand}.
 */
export interface ProvideAnomalyFeedbackCommandOutput extends ProvideAnomalyFeedbackResponse, __MetadataBearer {
}
/**
 * @public
 * <p>Modifies the feedback property of a given cost anomaly. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CostExplorerClient, ProvideAnomalyFeedbackCommand } from "@aws-sdk/client-cost-explorer"; // ES Modules import
 * // const { CostExplorerClient, ProvideAnomalyFeedbackCommand } = require("@aws-sdk/client-cost-explorer"); // CommonJS import
 * const client = new CostExplorerClient(config);
 * const input = { // ProvideAnomalyFeedbackRequest
 *   AnomalyId: "STRING_VALUE", // required
 *   Feedback: "YES" || "NO" || "PLANNED_ACTIVITY", // required
 * };
 * const command = new ProvideAnomalyFeedbackCommand(input);
 * const response = await client.send(command);
 * // { // ProvideAnomalyFeedbackResponse
 * //   AnomalyId: "STRING_VALUE", // required
 * // };
 *
 * ```
 *
 * @param ProvideAnomalyFeedbackCommandInput - {@link ProvideAnomalyFeedbackCommandInput}
 * @returns {@link ProvideAnomalyFeedbackCommandOutput}
 * @see {@link ProvideAnomalyFeedbackCommandInput} for command's `input` shape.
 * @see {@link ProvideAnomalyFeedbackCommandOutput} for command's `response` shape.
 * @see {@link CostExplorerClientResolvedConfig | config} for CostExplorerClient's `config` shape.
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>You made too many calls in a short period of time. Try again later.</p>
 *
 * @throws {@link CostExplorerServiceException}
 * <p>Base exception class for all service exceptions from CostExplorer service.</p>
 *
 */
export declare class ProvideAnomalyFeedbackCommand extends $Command<ProvideAnomalyFeedbackCommandInput, ProvideAnomalyFeedbackCommandOutput, CostExplorerClientResolvedConfig> {
    readonly input: ProvideAnomalyFeedbackCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: ProvideAnomalyFeedbackCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CostExplorerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ProvideAnomalyFeedbackCommandInput, ProvideAnomalyFeedbackCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
